@@ -1,9 +1,10 @@
-__version__ = '0.0.6'
+__version__ = '0.0.9'
 __author__ = 'Xiang Wang'
 
 # List maintainers here
 __maintainers__ = [
-    'Xiang Wang'
+    'Xiang Wang',
+    'ChenJie Shen'
 ]
 
 __all__ = [
